-- Libraries

local L = AceLibrary("AceLocale-2.2"):new("GridLayoutPlus")
local RL = AceLibrary("Roster-2.1")


-- New Grid status module

GridLayoutPlus = Grid:NewModule("GridLayoutPlus")
GridLayoutPlus.defaultDB = {
	autoGroupLayout = true,
}

	
-- Init

function GridLayoutPlus:OnEnable()
	local options = GridLayout.options.args
	options["autoGroupLayout"] = {
		type = "toggle",
		name = L["Auto adjust group layout"],
		desc = L["Automatically adjust layout to fit raid size"],
		get = function ()
			return GridLayout.db.profile.autoGroupLayout
		end,
		set = function (v)
			GridLayout.db.profile.autoGroupLayout = v
		end,	
	}
	self:RegisterEvent("RosterLib_RosterUpdated")
end


-- Additional Layouts

GridLayout:AddLayout(L["By Group 40 w/Pets (Plus)"], {
	[1] = {
		groupFilter = "1",
	},
	[2] = {
		groupFilter = "2",
	},
	[3] = {
		groupFilter = "3",
	},
	[4] = {
		groupFilter = "4",
	},
	[5] = {
		groupFilter = "5",
	},
	[6] = {
		groupFilter = "6",
	},
	[7] = {
		groupFilter = "7",
	},
	[8] = {
		groupFilter = "8",
	},
	[9] = {
		isPetGroup = true,
		groupFilter = "HUNTER,WARLOCK",
		unitsPerColumn = 5,
		maxColumns = 8,
		filterOnPet = true,
	},
})

GridLayout:AddLayout(L["By Group 35 w/Pets (Plus)"], {
	[1] = {
		groupFilter = "1",
	},
	[2] = {
		groupFilter = "2",
	},
	[3] = {
		groupFilter = "3",
	},
	[4] = {
		groupFilter = "4",
	},
	[5] = {
		groupFilter = "5",
	},
	[6] = {
		groupFilter = "6",
	},
	[7] = {
		groupFilter = "7",
	},
	[8] = {
		isPetGroup = true,
		groupFilter = "HUNTER,WARLOCK",
		unitsPerColumn = 5,
		maxColumns = 8,
		filterOnPet = true,
	},
})

GridLayout:AddLayout(L["By Group 30 w/Pets (Plus)"], {
	[1] = {
		groupFilter = "1",
	},
	[2] = {
		groupFilter = "2",
	},
	[3] = {
		groupFilter = "3",
	},
	[4] = {
		groupFilter = "4",
	},
	[5] = {
		groupFilter = "5",
	},
	[6] = {
		groupFilter = "6",
	},
	[7] = {
		isPetGroup = true,
		groupFilter = "HUNTER,WARLOCK",
		unitsPerColumn = 5,
		maxColumns = 8,
		filterOnPet = true,
	},
})

GridLayout:AddLayout(L["By Group 20 w/Pets (Plus)"], {
	[1] = {
		groupFilter = "1",
	},
	[2] = {
		groupFilter = "2",
	},
	[3] = {
		groupFilter = "3",
	},
	[4] = {
		groupFilter = "4",
	},
	[5] = {
		isPetGroup = true,
		groupFilter = "HUNTER,WARLOCK",
		unitsPerColumn = 5,
		maxColumns = 8,
		filterOnPet = true,
	},
})

GridLayout:AddLayout(L["By Group 15 w/Pets (Plus)"], {
	[1] = {
		groupFilter = "1",
	},
	[2] = {
		groupFilter = "2",
	},
	[3] = {
		groupFilter = "3",
	},
	[4] = {
		isPetGroup = true,
		groupFilter = "HUNTER,WARLOCK",
		unitsPerColumn = 5,
		maxColumns = 8,
		filterOnPet = true,
	},
})

GridLayout:AddLayout(L["By Group 5 w/Pets (Plus)"], {
	[1] = {
		groupFilter = "1",
	},
	[2] = {
		isPetGroup = true,
		groupFilter = "HUNTER,WARLOCK",
		unitsPerColumn = 5,
		maxColumns = 8,
		filterOnPet = true,
	},
})

GridLayout:AddLayout(L["By Sorted Class w/Pets (Plus)"], {
	[1] = {
		groupFilter = "WARRIOR,ROGUE,DRUID,PALADIN,SHAMAN,PRIEST,MAGE,WARLOCK,HUNTER",
		groupBy = "CLASS",
		groupingOrder = "WARRIOR,ROGUE,DRUID,PALADIN,SHAMAN,PRIEST,MAGE,WARLOCK,HUNTER",
		unitsPerColumn = 5,
		maxColumns = 8,
	},
	[2] = {
		isPetGroup = true,
		groupFilter = "HUNTER,WARLOCK",
		groupBy = "CLASS",
		groupingOrder = "HUNTER,WARLOCK",
		unitsPerColumn = 5,
		maxColumns = 8,
		filterOnPet = true,
	}
})


-- Event handlers

function GridLayoutPlus:RosterLib_RosterUpdated()
	if GridLayout.db.profile.autoSizeFrames and (GetNumRaidMembers() > 0) and string.find(GridLayout.db.profile.layout, L["By Group"]) and string.find(GridLayout.db.profile.layout, L["w/Pets"]) then
		local maxsubgroup = 0
		local newlayout = nil
		for u in RL:IterateRoster(nil) do
			if u.subgroup > maxsubgroup then
				maxsubgroup = u.subgroup
			end
		end
		if (maxsubgroup > 7) then
			newlayout = L["By Group 40 w/Pets (Plus)"]
		elseif (maxsubgroup > 6) then
			newlayout = L["By Group 35 w/Pets (Plus)"]
		elseif (maxsubgroup > 5) then
			newlayout = L["By Group 30 w/Pets (Plus)"]
		elseif (maxsubgroup > 4) then
			newlayout = L["By Group 25 w/Pets"]
		elseif (maxsubgroup > 3) then
			newlayout = L["By Group 20 w/Pets (Plus)"]
		elseif (maxsubgroup > 2) then
			newlayout = L["By Group 15 w/Pets (Plus)"]
		elseif (maxsubgroup > 1) then
			newlayout = L["By Group 10 w/Pets"]
		else
			newlayout = L["By Group 5 w/Pets (Plus)"]
		end
		if newlayout and (GridLayout.db.profile.layout ~= newlayout) then
			GridLayout.db.profile.layout = newlayout
			GridLayout:LoadLayout(newlayout)
		end
	end
end
